# mypy-boto3-events

[![PyPI - mypy-boto3-events](https://img.shields.io/pypi/v/mypy-boto3-events.svg?color=blue)](https://pypi.org/project/mypy-boto3-events)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-events.svg?color=blue)](https://pypi.org/project/mypy-boto3-events)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.EventBridge 1.16.7](https://boto3.amazonaws.com/v1/documentation/api/1.16.7/reference/services/events.html#EventBridge) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 3.2.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

- [mypy-boto3-events](#mypy-boto3-events)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `EventBridge` service.

```bash
python -m pip install boto3-stubs[events]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[events]` in your environment: `python -m pip install 'boto3-stubs[events]'`

Both type checking and auto-complete should work for `EventBridge` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[events]` in your environment: `python -m pip install 'boto3-stubs[events]'`

Both type checking and auto-complete should work for `EventBridge` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[events]` in your environment: `python -m pip install 'boto3-stubs[events]'`
- Run `mypy` as usual

Type checking should work for `EventBridge` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[events]` in your environment: `python -m pip install 'boto3-stubs[events]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `EventBridge` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`EventBridgeClient` provides annotations for `boto3.client("events")`.

```python
import boto3

from mypy_boto3_events import EventBridgeClient

client: EventBridgeClient = boto3.client("events")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: EventBridgeClient = session.client("events")
```

### Paginators annotations

`mypy_boto3_events.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_events import EventBridgeClient
from mypy_boto3_events.paginator import (
    ListRuleNamesByTargetPaginator,
    ListRulesPaginator,
    ListTargetsByRulePaginator,
)

client: EventBridgeClient = boto3.client("events")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_rule_names_by_target_paginator: ListRuleNamesByTargetPaginator = client.get_paginator("list_rule_names_by_target")
list_rules_paginator: ListRulesPaginator = client.get_paginator("list_rules")
list_targets_by_rule_paginator: ListTargetsByRulePaginator = client.get_paginator("list_targets_by_rule")
```







### Typed dictionations

`mypy_boto3_events.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_events.type_defs import (
    AwsVpcConfigurationTypeDef,
    BatchArrayPropertiesTypeDef,
    BatchParametersTypeDef,
    BatchRetryStrategyTypeDef,
    ConditionTypeDef,
    CreateEventBusResponseTypeDef,
    CreatePartnerEventSourceResponseTypeDef,
    DeadLetterConfigTypeDef,
    DescribeEventBusResponseTypeDef,
    DescribeEventSourceResponseTypeDef,
    DescribePartnerEventSourceResponseTypeDef,
    DescribeRuleResponseTypeDef,
    EcsParametersTypeDef,
    EventBusTypeDef,
    EventSourceTypeDef,
    HttpParametersTypeDef,
    InputTransformerTypeDef,
    KinesisParametersTypeDef,
    ListEventBusesResponseTypeDef,
    ListEventSourcesResponseTypeDef,
    ListPartnerEventSourceAccountsResponseTypeDef,
    ListPartnerEventSourcesResponseTypeDef,
    ListRuleNamesByTargetResponseTypeDef,
    ListRulesResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    ListTargetsByRuleResponseTypeDef,
    NetworkConfigurationTypeDef,
    PaginatorConfigTypeDef,
    PartnerEventSourceAccountTypeDef,
    PartnerEventSourceTypeDef,
    PutEventsRequestEntryTypeDef,
    PutEventsResponseTypeDef,
    PutEventsResultEntryTypeDef,
    PutPartnerEventsRequestEntryTypeDef,
    PutPartnerEventsResponseTypeDef,
    PutPartnerEventsResultEntryTypeDef,
    PutRuleResponseTypeDef,
    PutTargetsResponseTypeDef,
    PutTargetsResultEntryTypeDef,
    RedshiftDataParametersTypeDef,
    RemoveTargetsResponseTypeDef,
    RemoveTargetsResultEntryTypeDef,
    RetryPolicyTypeDef,
    RuleTypeDef,
    RunCommandParametersTypeDef,
    RunCommandTargetTypeDef,
    SqsParametersTypeDef,
    TagTypeDef,
    TargetTypeDef,
    TestEventPatternResponseTypeDef,
)

def get_structure() -> AwsVpcConfigurationTypeDef:
    return {
      ...
    }
```
